Welcome to Sahara!
==================

The sahara project aims to provide users with a simple means to provision data
processing frameworks (such as Apache Hadoop, Apache Spark and Apache Storm)
on OpenStack. This is accomplished by specifying configuration parameters such
as the framework version, cluster topology, node hardware details and more.

Overview
--------

.. toctree::
   :maxdepth: 2

   intro/index


Installation
------------

.. toctree::
   :maxdepth: 2

   install/index


Configuration
-------------

.. toctree::
   :maxdepth: 2

   configuration/index


User Guide
----------

.. toctree::
   :maxdepth: 2

   user/index


CLI Guide
---------

.. toctree::
   :maxdepth: 2

   cli/index


Operator Documentation
----------------------

.. toctree::
   :maxdepth: 2

   admin/index


Contributor Documentation
-------------------------

.. toctree::
   :maxdepth: 2

   contributor/index


Programming Reference
---------------------

.. toctree::
   :maxdepth: 2

   reference/index
